@@ -185,6 +185,20 @@ class Plugin():
                     clear.append(d)
         for d in clear:
             del data['paths'][d]
+        if "dictionary" in self.halo.settings:
+            dict_schemas = "schemas"
+            dict_name = "components"
+            if data["swagger"] in ["2.0"]:
+                dict_name = "definitions"
+                dict_schemas = None
+            if dict_name not in data:
+                data[dict_name] = {}
+            dict_target = data[dict_name]
+            if dict_schemas and dict_schemas not in data[dict_name]:
+                data[dict_name][dict_schemas] = {}
+                dict_target = data[dict_name][dict_schemas]
+            for var in self.halo.settings["dictionary"]:
+                dict_target[var] = self.halo.settings["dictionary"][var]
         if self.refactor or self.all:
             for k in tmp:
                 new_m = tmp[k]
@@ -202,7 +216,8 @@ class Plugin():
                             props = new_m[o]['responses']['201']['schema']['items']['properties']
                         else:
                             props = new_m[o]['responses']['201']['schema']['properties']
-                    for p in props:
+                    #for p in props:
+                    if True:
                         for target in self.halo.settings['mservices'][self.service]['record']['methods'][mthd]['refactor']:
                             fields = target['field'].split(".")
                             propsx = props
@@ -216,11 +231,24 @@ class Plugin():
                                         propsx = None
                                         break
                             if propsx:
-                                propsx['type'] = target['type']
+                                #refactor block
+                                #self.halo.cli.log(str(target)+"$"+str(o))
+                                if "type" in target:
+                                    propsx['type'] = target['type']
+                                if propsx['type'] == "string":
+                                    if "pattern" in target:
+                                        propsx['pattern'] = target['pattern']
+                                    if "minLength" in target:
+                                        propsx['minLength'] = target['minLength']
+                                    if "maxLength" in target:
+                                        propsx['maxLength'] = target['maxLength']
+                                if "$ref" in target:
+                                    if target['$ref'] in self.halo.settings['dictionary']:
+                                        propsx['$ref'] = '#/definitions/' + target['$ref']
                                 if "format" in target:
                                     propsx['format'] = target['format']
                                 if 'properties' in target:
-                                    propsx['properties'] = {}
+                                    propsx['properties'] = target['properties']
                 data['paths'][k] = new_m
             self.halo.cli.log("finished refactor successfully")
         # fix the response and add
@@ -245,7 +273,8 @@ class Plugin():
                             props = new_m[o]['responses']['201']['schema']['items']['properties']
                         else:
                             props = new_m[o]['responses']['201']['schema']['properties']
-                    for p in props:
+                    #for p in props:
+                    if True:
                         for target in self.halo.settings['mservices'][self.service]['record']['methods'][mthd]['added_fields']:
                             fields = target.split(".")
                             propsx = props
@@ -260,8 +289,8 @@ class Plugin():
                                         break
                             if propsx:
                                 for fld in self.halo.settings['mservices'][self.service]['record']['methods'][mthd]['added_fields'][target]:
-                                    type = self.halo.settings['mservices'][self.service]['record']['methods'][mthd]['added_fields'][target][fld]
-                                    propsx['properties'][fld] = type
+                                    val = self.halo.settings['mservices'][self.service]['record']['methods'][mthd]['added_fields'][target][fld]
+                                    propsx['properties'][fld] = val
                                     self.halo.cli.log(new_m['get']['operationId'] + ":" +fld)
                 data['paths'][k] = new_m
             self.halo.cli.log("finished fields successfully")
@@ -343,6 +372,18 @@ class Plugin():
                                         i = i + 1
                                     type = target['type']
                                     propsx['type'] = type
+                                    if propsx['type'] == "string":
+                                        if "pattern" in target:
+                                            propsx['pattern'] = target['pattern']
+                                        if "minLength" in target:
+                                            propsx['minLength'] = target['minLength']
+                                        if "maxLength" in target:
+                                            propsx['maxLength'] = target['maxLength']
+                                    if 'properties' in target:
+                                        propsx['properties'] = target['properties']
+                                    if "$ref" in target:
+                                        if target['$ref'] in self.halo.settings['dictionary']:
+                                            propsx['$ref'] = '#/definitions/' + target['$ref']
             data['paths'][k] = new_m
 
     def after_refactor_generate(self):
